# encoding: utf-8

# File:	clients/imanager_auto.ycp
# Package:	Configuration of imanager
# Summary:	Client for autoinstallation
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: imanager_auto.ycp,v 1.1.2.2 2004/10/15 17:57:43 mclark Exp $
#
# This is a client for autoinstallation. It takes its arguments,
# goes through the configuration and return the setting.
# Does not do any changes to the configuration.

# @param function to execute
# @param map/list of imanager settings
# @return [Hash] edited settings, Summary or boolean on success depending on called function
# @example map mm = $[ "FAIL_DELAY" : "77" ];
# @example map ret = WFM::CallFunction ("imanager_auto", [ "Summary", mm ]);
module Yast
  class ImanagerAutoClient < Client
    def main
      Yast.import "UI"

      textdomain "novell-imanager"

      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("Imanager auto started")

      Yast.import "Imanager"
      Yast.include self, "novell-imanager/wizards.rb"

      @ret = nil
      @func = ""
      @param = {}

      # Check arguments
      if Ops.greater_than(Builtins.size(WFM.Args), 0) &&
          Ops.is_string?(WFM.Args(0))
        @func = Convert.to_string(WFM.Args(0))
        if Ops.greater_than(Builtins.size(WFM.Args), 1) &&
            Ops.is_map?(WFM.Args(1))
          @param = Convert.to_map(WFM.Args(1))
        end
      end
      Builtins.y2debug("func=%1", @func)
      Builtins.y2debug("param=%1", @param)

      # Create a summary
      if @func == "Summary"
        @ret = Ops.get_string(Imanager.Summary, 0, "")
      # Reset configuration
      elsif @func == "Reset"
        Imanager.Import({})
        @ret = {}
      # Change configuration (run AutoSequence)
      elsif @func == "Change"
        @ret = ImanagerAutoSequence()
      # Import configuration
      elsif @func == "Import"
        @ret = Imanager.Import(@param)
      # Return actual state
      elsif @func == "Export"
        Imanager.Read if Imanager.Settings == nil || Imanager.Settings == {}
        Imanager.auto_clone = true
        @ret = Imanager.Export
      # Return needed packages
      elsif @func == "Packages"
        @ret = Imanager.AutoPackages
      # Read current state
      elsif @func == "Read"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        @ret = Imanager.Read
        Progress.set(@progress_orig)
      # Write givven settings
      elsif @func == "Write"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        Imanager.write_only = true
        @ret = Imanager.Write
        Progress.set(@progress_orig)
      # Return if configuration  was changed
      # return boolean
      elsif @func == "GetModified"
        Imanager.globals_configured = true
        @ret = Imanager.globals_configured
      # Set modified flag
      # return boolean
      elsif @func == "SetModified"
        Imanager.globals_configured = true
        @ret = true
      else
        Builtins.y2error("Unknown function: %1", @func)
        @ret = false
      end

      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("Imanager auto finished")
      Builtins.y2milestone("----------------------------------------")

      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::ImanagerAutoClient.new.main
