# encoding: utf-8

# File:	clients/imanager_proposal.ycp
# Package:	Configuration of imanager
# Summary:	Proposal function dispatcher.
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: imanager_proposal.ycp,v 1.1.2.10 2005/02/10 21:20:32 sbunch Exp $
#
# Proposal function dispatcher for imanager configuration.
# See source/installation/proposal/proposal-API.txt
module Yast
  class ImanagerProposalClient < Client
    def main

      textdomain "novell-imanager"

      Yast.import "Imanager"
      Yast.import "Progress"
      Yast.import "NovellLDAP"
      Yast.import "NovellPatterns"
      Yast.import "NovellAddonInstall"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("Imanager proposal started")

      @func = Convert.to_string(WFM.Args(0))
      @param = Convert.to_map(WFM.Args(1))
      @ret = {}

      # create a textual proposal
      if @func == "MakeProposal"
        @proposal = ""
        @warning = ""
        @warning_level = nil
        @force_reset = Ops.get_boolean(@param, "force_reset", false)

        if @force_reset || !Imanager.proposal_valid
          Imanager.proposal_valid = true
          @progress_orig = Progress.set(false)
          Imanager.Read
          Progress.set(@progress_orig)
        end
        @sum = Imanager.Summary
        @proposal = Ops.get_string(@sum, 0, "")
        @ret = NovellAddonInstall.ConstructProposal("imanager", @proposal)
      # validate the current values
      # Bug 298638. We have decided to not validate the ldap tree and user name.
      # This will allow the iManager configuration to continue in a post-install

      # run the module
      elsif @func == "AskUser"
        Builtins.sleep(750)
        @chosen_id = Ops.get(@param, "chosen_id")
        Builtins.y2milestone("iManager proposal changing id %1", @chosen_id)

        # Configure now
        if @chosen_id == "imanager--configure_now"
          Ops.set(NovellAddonInstall.products_to_configure, "imanager", true)
          @ret = { "workflow_sequence" => :next }
        elsif @chosen_id == "imanager--configure_later"
          Ops.set(NovellAddonInstall.products_to_configure, "imanager", false)
          @ret = { "workflow_sequence" => :next }
        else
          @stored = Imanager.Export
          @seq = Convert.to_symbol(
            WFM.CallFunction("imanager", [path(".propose")])
          )
          Imanager.Import(@stored) if @seq != :next
          Builtins.y2debug("stored=%1", @stored)
          Builtins.y2debug("seq=%1", @seq)
          @ret = { "workflow_sequence" => @seq }
        end
      # create titles
      elsif @func == "Description"
        # Determine if we should be in the proposal screen or not.
        @force_proposal = Ops.get_boolean(@param, "force_proposal", false)
        @isSelected = NovellPatterns.IsPatternInstalled("novell-imanager") # FIXME: is this needed anymore?
        @isSelected = @isSelected &&
          NovellAddonInstall.IsProductSelected("imanager")
        Builtins.y2milestone(
          "Proposal:IsSelected:novell-imanager: %1",
          @isSelected
        )
        if @isSelected || @force_proposal
          @ret = {
            # Rich text title for Imanager in proposals
            "rich_text_title" => _(
              "iManager"
            ),
            # Menu title for Imanager in proposals
            "menu_title"      => _(
              "iMana&ger"
            ),
            "id"              => "imanager"
          }
        else
          @ret = {}
        end
      # write the proposal
      elsif @func == "Write"
        Imanager.Write
      else
        Builtins.y2error("unknown function: %1", @func)
      end

      # Finish
      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("Imanager proposal finished")
      Builtins.y2milestone("----------------------------------------")
      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::ImanagerProposalClient.new.main
