# encoding: utf-8

# File:	include/novell-imanager/complex.ycp
# Package:	Configuration of imanager
# Summary:	Dialogs definitions
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: complex.ycp,v 1.1.2.3 2004/12/10 18:28:57 mclark Exp $
module Yast
  module NovellImanagerComplexInclude
    def initialize_novell_imanager_complex(include_target)
      Yast.import "UI"

      textdomain "novell-imanager"

      Yast.import "Label"
      Yast.import "Popup"
      Yast.import "Wizard"
      Yast.import "UIHelper"
      Yast.import "Imanager"

      Yast.include include_target, "novell-imanager/helps.rb"
    end

    # Return a modification status
    # @return true if data was modified
    def Modified
      Imanager.Modified
    end

    def ReallyAbort
      !Imanager.Modified || Popup.ReallyAbort(true)
    end

    def PollAbort
      UI.PollInput == :abort
    end

    # Read settings dialog
    # @return `abort if aborted and `next otherwise
    def ReadDialog
      Wizard.RestoreHelp(Ops.get_string(@HELPS, "read", ""))
      # Imanager::AbortFunction = PollAbort;
      ret = Imanager.Read
      ret ? :next : :abort
    end

    # Write settings dialog
    # @return `abort if aborted and `next otherwise
    def WriteDialog
      Wizard.RestoreHelp(Ops.get_string(@HELPS, "write", ""))
      # Imanager::AbortFunction = PollAbort;
      ret = Imanager.Write
      ret ? :next : :abort
    end

    # Summary dialog
    # @return dialog result
    def SummaryDialog
      # Imanager summary dialog caption
      caption = _("iManager Configuration")

      # FIXME
      summary = Imanager.Summary
      unconfigured = Ops.get_list(summary, 1, [])
      configured = Ops.get_string(summary, 0, "")

      # Frame label
      #    term contents = Wizard_hw::DetectedContent(_("iManager to Configure"),
      #	    unconfigured, false, configured);

      contents = nil
      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "summary", ""),
        Label.BackButton,
        Label.FinishButton
      )

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel || ret == :back
          if ReallyAbort()
            break
          else
            next
          end
        # overview dialog
        elsif ret == :edit_button
          ret = :overview
          break
        # configure the selected device
        elsif ret == :configure_button
          # TODO FIXME: check for change of the configuration
          selected = UI.QueryWidget(Id(:detected_selbox), :CurrentItem)
          if selected == :other
            ret = :other
          else
            ret = :configure
          end
          break
        elsif ret == :next
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end

      deep_copy(ret)
    end

    # Overview dialog
    # @return dialog result
    def OverviewDialog
      # Imanager overview dialog caption
      caption = _("iManager Overview")

      overview = Imanager.Overview

      # FIXME table header
      contents = UIHelper.EditTable(
        # Table header
        Header(_("Number"), _("iManager")),
        overview,
        nil,
        nil,
        nil,
        nil
      )

      contents = UIHelper.SpacingAround(contents, 1.5, 1.5, 1.0, 1.0)

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "overview", ""),
        Label.BackButton,
        Label.FinishButton
      )

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        # add
        elsif ret == :add_button
          # FIXME
          ret = :add
          break
        # edit
        elsif ret == :edit_button
          # FIXME
          ret = :edit
          break
        # delete
        elsif ret == :delete_button
          # FIXME
          next
        elsif ret == :next || ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end

      deep_copy(ret)
    end
  end
end
