# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2021 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:        include/novell-imanager/dialogs.ycp
# Package:     Configuration of imanager
# Summary:     Dialogs definitions
# Authors:     Mark Clark <mclark@novell.com>
#
# $Id: dialogs.ycp,v 1.1.2.5 2005/07/29 00:47:52 mclark Exp $
module Yast
  module NovellImanagerDialogsInclude
    def initialize_novell_imanager_dialogs(include_target)
      Yast.import "UI"

      textdomain "novell-imanager"

      Yast.import "Label"
      Yast.import "Wizard"
      Yast.import "Imanager"
      Yast.import "EdirUtils"
      Yast.import "NovellLDAP"
      Yast.import "NovellUtils"
      Yast.import "NovellValidators"

      Yast.include include_target, "novell-imanager/complex.rb"
      Yast.include include_target, "novell-imanager/helps.rb"
    end

    # Imanager dialog
    # @return dialog result
    def TreeUserDialog
      # iManager configure dialog caption
      caption = _("iManager Configuration")

      tree = Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", "")
      tree = "" if tree == nil

      user = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_CONTEXT",
        ""
      )
      if Imanager.xadMode
        xad_tree_admin_context = Ops.get_string(
          NovellLDAP.Settings,
          "XAD_TREE_ADMIN_CONTEXT",
          ""
        )
        Builtins.y2milestone(
          "Imanager:XAD_TREE_ADMIN_CONTEXT:%1",
          xad_tree_admin_context
        )
        if xad_tree_admin_context != nil && xad_tree_admin_context != ""
          user = NovellUtils.Nds2Ldap(xad_tree_admin_context)
        end
      end
      Builtins.y2milestone("Imanager:admin:%1", user)

      user = "" if user == nil

      installPlugins = false
      if Ops.get_string(
          Imanager.Settings,
          "CONFIG_IMANAGER_INSTALL_PLUGINS",
          ""
        ) == "yes"
        installPlugins = true
      end

      contents = HVSquash(
        VBox(
          Label(
            _(
              "These values cannot be edited here.  Use the eDirectory Configuration dialog."
            )
          ),
          VSpacing(1),
          TextEntry(Id(:iMtree), _("eDirectory tree"), tree),
          TextEntry(
            Id(:iMuser),
            _("&FDN admin name with context (i.e. cn=admin,o=microfocus)"),
            user
          ),
          VSpacing(2.0),
          Left(
            CheckBox(
              Id(:plugins),
              Opt(:notify),
              _("Don't install plugins now.")
            )
          )
        )
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "c1", ""),
        Label.BackButton,
        Label.NextButton
      )
      UI.ChangeWidget(Id(:iMtree), :Enabled, false)
      UI.ChangeWidget(Id(:iMuser), :Enabled, false)

      if installPlugins
        UI.ChangeWidget(Id(:plugins), :Value, false)
      else
        UI.ChangeWidget(Id(:plugins), :Value, true)
      end

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          dontInstallPlugins = Convert.to_boolean(
            UI.QueryWidget(Id(:plugins), :Value)
          )
          if dontInstallPlugins
            Ops.set(Imanager.Settings, "CONFIG_IMANAGER_INSTALL_PLUGINS", "no")
          else
            Ops.set(Imanager.Settings, "CONFIG_IMANAGER_INSTALL_PLUGINS", "yes")
          end

          break
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end
  end
end
