# encoding: utf-8

# File:        include/novell-imanager/wizards.ycp
# Package:     Configuration of imanager
# Summary:     Wizards definitions
# Authors:     Mark Clark <mclark@novell.com>
#
# $Id: wizards.ycp,v 1.1.2.3 2004/12/03 00:04:41 sbunch Exp $
module Yast
  module NovellImanagerWizardsInclude
    def initialize_novell_imanager_wizards(include_target)
      Yast.import "UI"

      textdomain "novell-imanager"

      Yast.import "Sequencer"
      Yast.import "Wizard"

      Yast.include include_target, "novell-imanager/complex.rb"
      Yast.include include_target, "novell-imanager/dialogs.rb"
    end

    # Main workflow of the iManager configuration
    # @return sequence result
    def MainSequence
      aliases = { "treeUser" => lambda { TreeUserDialog() } }

      sequence = {
        "ws_start" => "treeUser",
        "treeUser" => { :abort => :abort, :next => :next }
      }

      ret = Sequencer.Run(aliases, sequence)

      deep_copy(ret)
    end

    # Whole configuration of imanager
    # @return sequence result
    def ImanagerSequence
      aliases = {
        "read"  => [lambda { ReadDialog() }, true],
        "main"  => lambda { MainSequence() },
        "write" => [lambda { WriteDialog() }, true]
      }

      sequence = {
        "ws_start" => "read",
        "read"     => { :abort => :abort, :next => "main" },
        "main"     => { :abort => :abort, :next => "write" },
        "write"    => { :abort => :abort, :next => :next }
      }

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("imanager")

      ret = Sequencer.Run(aliases, sequence)

      UI.CloseDialog
      deep_copy(ret)
    end

    # Whole configuration of imanager but without reading and writing.
    # For use with autoinstallation.
    # @return sequence result
    def ImanagerAutoSequence
      # Initialization dialog caption
      caption = _("iManager Configuration")
      # Initialization dialog contents
      contents = Label(_("Initializing..."))

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("imanager")
      Wizard.SetContentsButtons(
        caption,
        contents,
        "",
        Label.BackButton,
        Label.NextButton
      )

      ret = MainSequence()

      UI.CloseDialog
      deep_copy(ret)
    end
  end
end
